..
    This file is part of Invenio.
    Copyright (C) 2015 CERN.

    Invenio is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA 02111-1307, USA.

    In applying this license, CERN does not
    waive the privileges and immunities granted to it by virtue of its status
    as an Intergovernmental Organization or submit itself to any jurisdiction.


Authors
=======

Jinja utilities for Invenio.

- Adrian Pawel Baran <adrian.pawel.baran@cern.ch>
- Alessio Deiana <alessio.deiana@cern.ch>
- Benoit Thiell <bthiell@cfa.harvard.edu>
- Björn Oltmanns <bjoern.oltmanns@gmail.com>
- Christopher Dickinson <christopher.dickinson@cern.ch>
- Diane Berkovits <diane.berkovits@cern.ch>
- Eamonn Maguire <eamonnmag@gmail.com>
- Eirini Psallida <eirini.psallida@cern.ch>
- Esteban J. G. Gabancho <esteban.gabancho@cern.ch>
- Ferran Jorba <Ferran.Jorba@uab.cat>
- Gabriel Hase <gabriel.hase@cern.ch>
- Georgios Papoutsakis <georgios.papoutsakis@cern.ch>
- Giovanni Di Milia <gdimilia@cfa.harvard.edu>
- Grzegorz Szpura <grzegorz.szpura@cern.ch>
- Henning Weiler <henning.weiler@cern.ch>
- Ilias Koutsakis <ilias.koutsakis@cern.ch>
- Ivan Masár <helix84@centrum.sk>
- Jaime García <jaime.garcia.llopis@gmail.com>
- Jan Aage Lavik <jan.age.lavik@cern.ch>
- Jan Iwaszkiewicz <jan.iwaszkiewicz@cern.ch>
- Javier Martin <javier.martin.montull@cern.ch>
- Javier Martin Montull <javier.martin.montull@cern.ch>
- Jerome Caffaro <jerome.caffaro@cern.ch>
- Jiri Kuncar <jiri.kuncar@cern.ch>
- Joaquim Rodrigues Silvestre <joaquim.rodrigues.silvestre@cern.ch>
- Kamil Neczaj <kamil.neczaj@cern.ch>
- Konstantinos Kostis <konstantinos.kostis@cern.ch>
- Krzysztof Lis <krzysztof.lis@cern.ch>
- Lars Christian Raae <lars.christian.raae@cern.ch>
- Lars Holm Nielsen <lars.holm.nielsen@cern.ch>
- Leonardo Rossi <leonardo.r@cern.ch>
- Ludmila Marian <ludmila.marian@gmail.com>
- Marko Niinimaki <manzikki@gmail.com>
- Martin Vesely <martin.vesely@cern.ch>
- Mateusz Susik <mateusz.susik@cern.ch>
- Mathieu Barras <mbarras@gmail.com>
- Nicholas Robinson <nicholas.robinson@cern.ch>
- Nikolaos Kasioumis <nikolaos.kasioumis@cern.ch>
- Nikolay Dyankov <ndyankov@gmail.com>
- Patrick Glauner <patrick.oliver.glauner@cern.ch>
- Peter Halliday <phalliday@cornell.edu>
- Piotr Praczyk <piotr.praczyk@gmail.com>
- Raja Sripada <rsripada@cern.ch>
- Raquel Jimenez Encinar <r.jimenez.encinar@gmail.com>
- Samuele Carli <samuele.carli@cern.ch>
- Samuele Kaplun <samuele.kaplun@cern.ch>
- Stamen Todorov Peev <stamen.peev@cern.ch>
- Theodoropoulos Theodoros <theod@lib.auth.gr>
- Thomas Baron <thomas.baron@cern.ch>
- Tibor Simko <tibor.simko@cern.ch>
- Travis Brooks <travis@slac.stanford.edu>
- Trond Aksel Myklebust <trond.aksel.myklebust@cern.ch>
- Valkyrie Savage <vasavage@gmail.com>
- Yannick Tapparel <yannick.tapparel@cern.ch>
- Yoan Blanc <yoan.blanc@cern.ch>
- Kamil Neczaj <kneczaj@gmail.com>
- Øystein Blixhavn <oystein@blixhavn.no>
